## Static files

Sources:

jQuery:

* https://cdnjs.cloudflare.com/ajax/libs/jquery/3.1.0/jquery.min.js

Nanogallery:

* https://cdn.jsdelivr.net/npm/nanogallery2/dist/jquery.nanogallery2.min.js
* https://cdn.jsdelivr.net/npm/nanogallery2/dist/css/nanogallery2.min.css
* https://cdn.jsdelivr.net/npm/nanogallery2/dist/css/font/ngy2_icon_font.woff

These are not included in the distribution for license reasons. They are GPLv3. But download them yourself and add them as:


* ./jquery.nanogallery2.min.js
* ./nanogallery2.min.css
* ./font/ngy2_icon_font.woff
